@@ -2,6 +2,7 @@
  * Add contact dialog
  *
  * Copyright (C) 2011 David Edmundson <kde@davidedmundson.co.uk>
+ * Copyright (C) 2012 George Kiagiadakis <kiagiadakis.george@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,10 +28,9 @@
 
 #include <KTp/ktp-export.h>
 
-namespace Ui {
-    class AddContactDialog;
+namespace Tp {
+    class PendingOperation;
 }
-
 class AccountsModel;
 
 namespace KTp
@@ -42,11 +42,21 @@ class KTP_EXPORT AddContactDialog : public KDialog
 public:
     explicit AddContactDialog(AccountsModel* accountModel, QWidget *parent = 0);
     virtual ~AddContactDialog();
-    Tp::AccountPtr account() const;
-    const QString screenName() const;
+
+    virtual void accept();
+
+protected:
+    virtual void closeEvent(QCloseEvent *e);
+
+private Q_SLOTS:
+    KTP_NO_EXPORT void _k_onContactsForIdentifiersFinished(Tp::PendingOperation *op);
+    KTP_NO_EXPORT void _k_onRequestPresenceSubscriptionFinished(Tp::PendingOperation *op);
 
 private:
-    Ui::AddContactDialog *ui;
+    KTP_NO_EXPORT void setInProgress(bool inProgress);
+
+    struct Private;
+    Private * const d;
 };
 }
 
